/**
 * @copyright nhcarrigan
 * @license Naomi's Public License
 * @author Naomi Carrigan
 */
/* eslint-disable react/jsx-no-bind */
"use client";
import { faAndroid, faAppStore } from "@fortawesome/free-brands-svg-icons";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import { useState, type JSX } from "react";

interface PlayProperties {
  name:    string;
  userId:  string;
  android: string;
  ios:     string;
  server?: string;
  guild?: {
    name: string;
    id:   string;
  };
}

const copyToClipboard = (text: string): void => {
  void navigator.clipboard.writeText(text);
};

/**
 * Renders the view for a mobile game.
 * @param properties - The game to render.
 * @returns A JSX element.
 */
export const PlayComponent = (properties: PlayProperties): JSX.Element => {
  const { name, android, ios, server, guild, userId } = properties;

  const [ isFriendCodeCopied, setIsFriendCodeCopied ]
    = useState<boolean>(false);
  const [ isGuildIdCopied, setIsGuildIdCopied ]
    = useState<boolean>(false);

  const columns = guild
    ? "grid-cols-[2fr,1fr,200px]"
    : "grid-cols-[2fr,200px]";

  return (
    <div className={`grid items-center gap-2.5 pb-10 w-full ${columns}`}>
      <button
        className="border-solid border-2 rounded-full p-2
          text-[--background] bg-[--foreground]
          hover:bg-[--background] hover:text-[--foreground]"
        onClick={() => {
          copyToClipboard(userId);
          setIsFriendCodeCopied(true);
          setTimeout(() => {
            setIsFriendCodeCopied(false);
          }, 2000);
        }}
        type="button"
      >
        <h2 className="text-2xl">{name}</h2>
        <p>{`Friend Code: ${isFriendCodeCopied
          ? "Copied!"
          : userId}`}</p>
        {typeof server === "string"
          ? <p className="text-sm">{`Server: ${server}`}</p>
          : null}
      </button>
      {guild
        ? <button
          className="border-solid border-2 rounded-full p-2
            text-[--background] bg-[--foreground]
            hover:bg-[--background] hover:text-[--foreground]"
          onClick={() => {
            copyToClipboard(userId);
            setIsGuildIdCopied(true);
            setTimeout(() => {
              setIsGuildIdCopied(false);
            }, 2000);
          }}
          type="button"
        >
          <p className="text-2xl">{"Guild"}</p>
          <p>{guild.name}</p>
          <p className="text-sm">{`ID: ${isGuildIdCopied
            ? "Copied!"
            : guild.id}`}</p>
        </button>
        : null}
      <div className="flex">
        <a
          aria-label={`Play ${name} on Android`}
          className="flex m-auto justify-between
            items-center border-solid border-2 rounded-full p-2
            bg-[#3DDC84] text-[#FFFFFF] hover:bg-[#FFFFFF] hover:text-[#3DDC84]"
          href={android}
          rel="noreferrer"
          target="_blank"
        >
          <FontAwesomeIcon icon={faAndroid} size="3x" />
        </a>
        <a
          aria-label={`Play ${name} on iOS`}
          className="flex m-auto justify-between
            items-center border-solid border-2 rounded-full p-2
            bg-[#1ba7f8] text-[#FFFFFF] hover:bg-[#FFFFFF] hover:text-[#1ba7f8]"
          href={ios}
          rel="noreferrer"
          target="_blank"
        >
          <FontAwesomeIcon icon={faAppStore} size="3x" />
        </a>
      </div>
    </div>
  );
};
